@@ -168,6 +168,7 @@ b'\x01' : 'UBX-NAV',
 b'\x02' : 'UBX-RXM',
 b'\x05' : 'UBX-ACK',
 b'\x09' : 'UBX-ESF',
+b'\x0A' : 'UBX-MON',
 b'\x0B' : 'UBX-AID',
 b'\x0D' : 'UBX-TIM',
 b'\x10' : 'UBX-ESF',
@@ -184,8 +185,53 @@ b'\xF5' : 'RTCM'
 THESE ARE THE CONFIG MESSAGE TYPES (CFG-MSG)
 NB: Available messages will depend on the receiver
 '''
-# TODO add UBX message types
+# TODO add additional UBX message types for AID, RXM, ESF
 UBX_CONFIG_MESSAGES = {
+b'\x0A\x36': 'MON-COMMS',
+b'\x0A\x09': 'MON-HW',
+b'\x0A\x0B': 'MON-HW2',
+b'\x0A\x37': 'MON-HW3',
+b'\x0A\x02': 'MON-IO',
+b'\x0A\x06': 'MON-MSGPP',
+b'\x0A\x38': 'MON-RF',
+b'\x0A\x07': 'MON-RXBUF',
+b'\x0A\x21': 'MON-RXR',
+b'\x0A\x2E': 'MON-SMGR',
+b'\x0A\x31': 'MON-SPAN',
+b'\x0A\x08': 'MON-TXBUF',
+b'\x01\x60': 'NAV-AOPSTATUS',
+b'\x01\x05': 'NAV-ATT',
+b'\x01\x22': 'NAV-CLOCK',
+b'\x01\x31': 'NAV-DGPS',
+b'\x01\x04': 'NAV-DOP',
+b'\x01\x40': 'NAV-EKFSTATUS',
+b'\x01\x61': 'NAV-EOE',
+b'\x01\x39': 'NAV-GEOFENCE',
+b'\x01\x13': 'NAV-HPPOSECEF',
+b'\x01\x14': 'NAV-HPPOSLLH',
+b'\x01\x28': 'NAV-NMI',
+b'\x01\x09': 'NAV-ODO',
+b'\x01\x34': 'NAV-ORB',
+b'\x01\x01': 'NAV-POSECEF',
+b'\x01\x02': 'NAV-POSLLH',
+b'\x01\x07': 'NAV-PVT',
+b'\x01\x3C': 'NAV-RELPOSNED',
+b'\x01\x35': 'NAV-SAT',
+b'\x01\x32': 'NAV-SBAS',
+b'\x01\x43': 'NAV-SIG',
+b'\x01\x42': 'NAV-SLAS',
+b'\x01\x06': 'NAV-SOL',
+b'\x01\x03': 'NAV-STATUS',
+b'\x01\x30': 'NAV-SVINFO',
+b'\x01\x3B': 'NAV-SVIN',
+b'\x01\x24': 'NAV-TIMEBDS',
+b'\x01\x25': 'NAV-TIMEGAL',
+b'\x01\x23': 'NAV-TIMEGLO',
+b'\x01\x26': 'NAV-TIMELS',
+b'\x01\x27': 'NAV-TIMEQZSS',
+b'\x01\x21': 'NAV-TIMEUTC',
+b'\x01\x11': 'NAV-VELECEF',
+b'\x01\x12': 'NAV-VELNED',
 b'\xF1\x00': 'UBX-00',  # Lat/Long Position Data
 b'\xF1\x03': 'UBX-03',  # Satellite Status
 b'\xF1\x04': 'UBX-04',  # Time of Day and Clock Information
